==> xcsoar-6.8.13.tar.xz: xcsoar-6.8.13/src/BallastDumpManager.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef BALLAST_DUMP_MANAGER_HPP
#define BALLAST_DUMP_MANAGER_HPP

#include "Time/PeriodClock.hpp"

class GlidePolar;

class BallastDumpManager
{
  bool enabled;
  PeriodClock ballast_clock;

public:
  constexpr BallastDumpManager():enabled(false) {}

  bool IsEnabled() const {
    return enabled;
  }

  void Start();
  void Stop();

  void SetEnabled(bool _enabled);

  /**
   * Updates the ballast of the given GlidePolar.
   * This function must not be called if the BallastDumpManager is not enabled!
   * @param glide_polar The GlidePolar to update
   * @param dump_time Time that it takes to dump the entire ballast
   * @return True if ballast is not entirely dumped yet,
   *         False if we are dry now or dump_time is zero/unknown
   */
  bool Update(GlidePolar &glide_polar, unsigned dump_time);
};

#endif

==> xcsoar-7.12.tar.xz: xcsoar-7.12/src/BallastDumpManager.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef BALLAST_DUMP_MANAGER_HPP
#define BALLAST_DUMP_MANAGER_HPP

#include "time/PeriodClock.hpp"

class GlidePolar;

class BallastDumpManager
{
  bool enabled = false;
  PeriodClock ballast_clock;

public:
  bool IsEnabled() const noexcept {
    return enabled;
  }

  void Start() noexcept;
  void Stop() noexcept;

  void SetEnabled(bool _enabled) noexcept;

  /**
   * Updates the ballast of the given GlidePolar.
   * This function must not be called if the BallastDumpManager is not enabled!
   * @param glide_polar The GlidePolar to update
   * @param dump_time Time that it takes to dump the entire ballast
   * @return True if ballast is not entirely dumped yet,
   *         False if we are dry now or dump_time is zero/unknown
   */
  bool Update(GlidePolar &glide_polar, unsigned dump_time) noexcept;
};

#endif
